@@ -18,6 +18,9 @@
 // program with any Open Source program, as defined by the Open Source
 // Initiative (www.opensource.org)
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
 #include <octave/oct.h>
 
 static bool
