@@ -18,8 +18,15 @@
 // program with any Open Source program, as defined by the Open Source
 // Initiative (www.opensource.org)
 
-#include <octave/config.h>
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+#include <octave/oct.h>
+#ifdef HAVE_OCTAVE_OVL_H
+#include <octave/ovl.h>
+#elif HAVE_OCTAVE_OCT_OBJ_H
 #include <octave/oct-obj.h>
+#endif
 #include <octave/ops.h>
 
 #include "galois.h"
@@ -86,6 +93,7 @@ DEFCATOP_G_METHOD (gm_gm, galois, galois, concat)
 
 DEFASSIGNOP_FN (assign, galois, galois, assign)
 
+#ifndef DEFMETHOD_DLD
 void
 install_gm_gm_ops (void)
 {
@@ -113,11 +121,45 @@ install_gm_gm_ops (void)
   INSTALL_BINOP (op_el_ldiv, octave_galois, octave_galois, el_ldiv);
   INSTALL_BINOP (op_el_and, octave_galois, octave_galois, el_and);
   INSTALL_BINOP (op_el_or, octave_galois, octave_galois, el_or);
-
+ 
   INSTALL_G_CATOP (octave_galois, octave_galois, gm_gm);
 
   INSTALL_ASSIGNOP (op_asn_eq, octave_galois, octave_galois, assign);
 }
+#else
+void
+install_gm_gm_ops (octave::type_info& ti)
+{
+  INSTALL_UNOP_TI (ti, op_not, octave_galois, not);
+  INSTALL_UNOP_TI (ti, op_uminus, octave_galois, uminus);
+  INSTALL_UNOP_TI (ti, op_uplus, octave_galois, uplus);
+  INSTALL_UNOP_TI (ti, op_transpose, octave_galois, transpose);
+  INSTALL_UNOP_TI (ti, op_hermitian, octave_galois, transpose);
+
+  INSTALL_BINOP_TI (ti, op_add, octave_galois, octave_galois, add);
+  INSTALL_BINOP_TI (ti, op_sub, octave_galois, octave_galois, sub);
+  INSTALL_BINOP_TI (ti, op_mul, octave_galois, octave_galois, mul);
+  INSTALL_BINOP_TI (ti, op_div, octave_galois, octave_galois, div);
+  INSTALL_BINOP_TI (ti, op_pow, octave_galois, octave_galois, pow);
+  INSTALL_BINOP_TI (ti, op_ldiv, octave_galois, octave_galois, ldiv);
+  INSTALL_BINOP_TI (ti, op_lt, octave_galois, octave_galois, lt);
+  INSTALL_BINOP_TI (ti, op_le, octave_galois, octave_galois, le);
+  INSTALL_BINOP_TI (ti, op_eq, octave_galois, octave_galois, eq);
+  INSTALL_BINOP_TI (ti, op_ge, octave_galois, octave_galois, ge);
+  INSTALL_BINOP_TI (ti, op_gt, octave_galois, octave_galois, gt);
+  INSTALL_BINOP_TI (ti, op_ne, octave_galois, octave_galois, ne);
+  INSTALL_BINOP_TI (ti, op_el_mul, octave_galois, octave_galois, el_mul);
+  INSTALL_BINOP_TI (ti, op_el_div, octave_galois, octave_galois, el_div);
+  INSTALL_BINOP_TI (ti, op_el_pow, octave_galois, octave_galois, el_pow);
+  INSTALL_BINOP_TI (ti, op_el_ldiv, octave_galois, octave_galois, el_ldiv);
+  INSTALL_BINOP_TI (ti, op_el_and, octave_galois, octave_galois, el_and);
+  INSTALL_BINOP_TI (ti, op_el_or, octave_galois, octave_galois, el_or);
+ 
+  INSTALL_CATOP_TI (ti, octave_galois, octave_galois, gm_gm);
+
+  INSTALL_ASSIGNOP_TI (ti, op_asn_eq, octave_galois, octave_galois, assign);
+}
+#endif
 
 /*
 ;;; Local Variables: ***
