@@ -18,7 +18,10 @@
 // program with any Open Source program, as defined by the Open Source
 // Initiative (www.opensource.org)
 
-#include <octave/config.h>
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+#include <octave/oct.h>
 #include <octave/ops.h>
 #include <octave/ov-re-mat.h>
 
@@ -76,6 +79,7 @@ DEFCATOP_G_FN (m_gm, matrix, galois, concat)
 
 DEFASSIGNOP_FN (assign, matrix, galois, assign)
 
+#ifndef DEFMETHOD_DLD
 void
 install_m_gm_ops (void)
 {
@@ -103,7 +107,35 @@ install_m_gm_ops (void)
   INSTALL_ASSIGNOP (op_asn_eq, octave_matrix, octave_galois, assign);
   //INSTALL_ASSIGNCONV (octave_base_value, octave_matrix, octave_galois);
 }
-
+#else
+void
+install_m_gm_ops (octave::type_info& ti)
+{
+  INSTALL_BINOP_TI (ti, op_add, octave_matrix, octave_galois, add);
+  INSTALL_BINOP_TI (ti, op_sub, octave_matrix, octave_galois, sub);
+  INSTALL_BINOP_TI (ti, op_mul, octave_matrix, octave_galois, mul);
+  INSTALL_BINOP_TI (ti, op_div, octave_matrix, octave_galois, div);
+  INSTALL_BINOP_TI (ti, op_pow, octave_matrix, octave_galois, pow);
+  INSTALL_BINOP_TI (ti, op_ldiv, octave_matrix, octave_galois, ldiv);
+  INSTALL_BINOP_TI (ti, op_lt, octave_matrix, octave_galois, lt);
+  INSTALL_BINOP_TI (ti, op_le, octave_matrix, octave_galois, le);
+  INSTALL_BINOP_TI (ti, op_eq, octave_matrix, octave_galois, eq);
+  INSTALL_BINOP_TI (ti, op_ge, octave_matrix, octave_galois, ge);
+  INSTALL_BINOP_TI (ti, op_gt, octave_matrix, octave_galois, gt);
+  INSTALL_BINOP_TI (ti, op_ne, octave_matrix, octave_galois, ne);
+  INSTALL_BINOP_TI (ti, op_el_mul, octave_matrix, octave_galois, el_mul);
+  INSTALL_BINOP_TI (ti, op_el_div, octave_matrix, octave_galois, el_div);
+  INSTALL_BINOP_TI (ti, op_el_pow, octave_matrix, octave_galois, el_pow);
+  INSTALL_BINOP_TI (ti, op_el_ldiv, octave_matrix, octave_galois, el_ldiv);
+  INSTALL_BINOP_TI (ti, op_el_and, octave_matrix, octave_galois, el_and);
+  INSTALL_BINOP_TI (ti, op_el_or, octave_matrix, octave_galois, el_or);
+ 
+  INSTALL_CATOP_TI (ti, octave_matrix, octave_galois, m_gm);
+ 
+  INSTALL_ASSIGNOP_TI (ti, op_asn_eq, octave_matrix, octave_galois, assign);
+  //INSTALL_ASSIGNCONV (octave_base_value, octave_matrix, octave_galois);
+}
+#endif
 /*
 ;;; Local Variables: ***
 ;;; mode: C++ ***
